[open-ils-commits] [GIT] Evergreen ILS branch master updated. 8b34a4f5fd916e057fc127350bfc4c34c859d097

Evergreen Git git at git.evergreen-ils.org
Fri Jun 9 11:39:21 EDT 2017


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Evergreen ILS".

The branch, master has been updated
       via  8b34a4f5fd916e057fc127350bfc4c34c859d097 (commit)
       via  fe44ac279bed352c3a49a8a2c69e84c5a8e2ee43 (commit)
       via  96c30ebbd617c6ab3ab03dcb77294cb9f4c321cf (commit)
       via  0584c40feb01c666e82e0ff3ac178a3cbeea5991 (commit)
       via  2e7dfb9cca26c73ea3f6e87637fed03de902e5ca (commit)
       via  3992d368ac9d08aef664c55876ad155cc396a2a5 (commit)
       via  1cedb423902810e9df5355ab18c7ca7e18d5391d (commit)
      from  9b5cbea1fed81df6d10b74ce6b2b07e51ff84e7a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 8b34a4f5fd916e057fc127350bfc4c34c859d097
Author: Galen Charlton <gmc at equinoxinitiative.org>
Date:   Fri Jun 9 11:39:42 2017 -0400

    LP#1612752: apply terminology change to web staff
    
    Signed-off-by: Galen Charlton <gmc at equinoxinitiative.org>

diff --git a/Open-ILS/src/templates/staff/circ/share/t_abort_transit_dialog.tt2 b/Open-ILS/src/templates/staff/circ/share/t_abort_transit_dialog.tt2
index 7490e53..df89279 100644
--- a/Open-ILS/src/templates/staff/circ/share/t_abort_transit_dialog.tt2
+++ b/Open-ILS/src/templates/staff/circ/share/t_abort_transit_dialog.tt2
@@ -4,15 +4,15 @@
       <button type="button" class="close" 
         ng-click="cancel($event)" aria-hidden="true">×</button>
       <h4 class="modal-title">
-        [% l('Abort Transits and Reset Associated Holds') %]
+        [% l('Cancel Transits and Reset Associated Holds') %]
       </h4>
     </div>
     <div class="modal-body">
       <span class="form-group">
         <ng-pluralize count="num_transits"
             when="{
-                'one': '[% l('Abort 1 transit?') %]',
-                'other' : '[% l('Abort [_1] transits?','{{num_transits}}') %]'
+                'one': '[% l('Cancel 1 transit?') %]',
+                'other' : '[% l('Cancel [_1] transits?','{{num_transits}}') %]'
             }">
         </ng-pluralize>
         <ng-pluralize count="num_hold_transits"
@@ -24,7 +24,7 @@
       </span>
     </div>
     <div class="modal-footer">
-      <input type="submit" class="btn btn-success" value="[% l('Abort Transit') %]"/>
+      <input type="submit" class="btn btn-success" value="[% l('Cancel Transit') %]"/>
       <button class="btn btn-warning" ng-click="cancel($event)">[% l('Exit') %]</button>
     </div>
   </div>
diff --git a/Open-ILS/src/templates/staff/circ/transits/t_list.tt2 b/Open-ILS/src/templates/staff/circ/transits/t_list.tt2
index 3359a12..984bc23 100644
--- a/Open-ILS/src/templates/staff/circ/transits/t_list.tt2
+++ b/Open-ILS/src/templates/staff/circ/transits/t_list.tt2
@@ -39,7 +39,7 @@
     label="[% l('Edit Item Attributes') %]"></eg-grid-menu-item>
 
   <eg-grid-menu-item handler="abort_transit" 
-    label="[% l('Abort Transit') %]"></eg-grid-menu-item>
+    label="[% l('Cancel Transit') %]"></eg-grid-menu-item>
   <eg-grid-menu-item handler="print_full_list"
     label="[% l('Print Transits') %]"></eg-grid-menu-item>
 

commit fe44ac279bed352c3a49a8a2c69e84c5a8e2ee43
Author: Galen Charlton <gmc at equinoxinitiative.org>
Date:   Fri Jun 9 11:31:48 2017 -0400

    LP#1612752: stamp schema update
    
    Signed-off-by: Galen Charlton <gmc at equinoxinitiative.org>

diff --git a/Open-ILS/src/sql/Pg/002.schema.config.sql b/Open-ILS/src/sql/Pg/002.schema.config.sql
index b19894a..df2bb56 100644
--- a/Open-ILS/src/sql/Pg/002.schema.config.sql
+++ b/Open-ILS/src/sql/Pg/002.schema.config.sql
@@ -90,7 +90,7 @@ CREATE TRIGGER no_overlapping_deps
     BEFORE INSERT OR UPDATE ON config.db_patch_dependencies
     FOR EACH ROW EXECUTE PROCEDURE evergreen.array_overlap_check ('deprecates');
 
-INSERT INTO config.upgrade_log (version, applied_to) VALUES ('1044', :eg_version); -- berick/gmcharlt
+INSERT INTO config.upgrade_log (version, applied_to) VALUES ('1045', :eg_version); -- csharp/berick/gmcharlt
 
 CREATE TABLE config.bib_source (
 	id		SERIAL	PRIMARY KEY,
diff --git a/Open-ILS/src/sql/Pg/upgrade/XXXX-create-transit-cancel-time-column.sql b/Open-ILS/src/sql/Pg/upgrade/1045.schema.create-transit-cancel-time-column.sql
similarity index 91%
rename from Open-ILS/src/sql/Pg/upgrade/XXXX-create-transit-cancel-time-column.sql
rename to Open-ILS/src/sql/Pg/upgrade/1045.schema.create-transit-cancel-time-column.sql
index 57766f5..b4ae8ff 100644
--- a/Open-ILS/src/sql/Pg/upgrade/XXXX-create-transit-cancel-time-column.sql
+++ b/Open-ILS/src/sql/Pg/upgrade/1045.schema.create-transit-cancel-time-column.sql
@@ -1,6 +1,6 @@
 BEGIN;
 
-SELECT evergreen.upgrade_deps_block_check('XXXX', :eg_version);
+INSERT INTO config.upgrade_log (version, applied_to) VALUES ('1045', :eg_version); -- csharp/berick/gmcharlt
 
 ALTER TABLE action.transit_copy
 	ADD COLUMN cancel_time TIMESTAMPTZ;

commit 96c30ebbd617c6ab3ab03dcb77294cb9f4c321cf
Author: Bill Erickson <berickxx at gmail.com>
Date:   Tue May 16 12:06:37 2017 -0400

    LP#1612752 No canceled transits in webstaff transit list
    
    Avoid displaying canceled (previously aborted/deleted) transits in the
    web staff Transit List interface.
    
    Signed-off-by: Bill Erickson <berickxx at gmail.com>
    Signed-off-by: Galen Charlton <gmc at equinoxinitiative.org>

diff --git a/Open-ILS/web/js/ui/default/staff/circ/transits/list.js b/Open-ILS/web/js/ui/default/staff/circ/transits/list.js
index 4ae321f..9fb8a97 100644
--- a/Open-ILS/web/js/ui/default/staff/circ/transits/list.js
+++ b/Open-ILS/web/js/ui/default/staff/circ/transits/list.js
@@ -212,7 +212,8 @@ function($scope , $q , $routeParams , $window , egCore , egTransits , egGridData
     function current_query() {
         var filter = {
             'source_send_time' : { 'between' : date_range() },
-            'dest_recv_time'   : null
+            'dest_recv_time'   : null,
+            'cancel_time'      : null
         };
         if ($scope.transit_direction == 'to') { filter['dest'] = $scope.context_org.id(); }
         if ($scope.transit_direction == 'from') { filter['source'] = $scope.context_org.id(); }

commit 0584c40feb01c666e82e0ff3ac178a3cbeea5991
Author: Chris Sharp <csharp at georgialibraries.org>
Date:   Tue Feb 21 07:23:42 2017 -0500

    LP#1612752 - Do not clobber local perm description changes.
    
    Signed-off-by: Chris Sharp <csharp at georgialibraries.org>
    Signed-off-by: Bill Erickson <berickxx at gmail.com>
    Signed-off-by: Galen Charlton <gmc at equinoxinitiative.org>

diff --git a/Open-ILS/src/sql/Pg/upgrade/XXXX-create-transit-cancel-time-column.sql b/Open-ILS/src/sql/Pg/upgrade/XXXX-create-transit-cancel-time-column.sql
index a2709f6..57766f5 100644
--- a/Open-ILS/src/sql/Pg/upgrade/XXXX-create-transit-cancel-time-column.sql
+++ b/Open-ILS/src/sql/Pg/upgrade/XXXX-create-transit-cancel-time-column.sql
@@ -5,10 +5,21 @@ SELECT evergreen.upgrade_deps_block_check('XXXX', :eg_version);
 ALTER TABLE action.transit_copy
 	ADD COLUMN cancel_time TIMESTAMPTZ;
 
--- change "abort" to "cancel" in perm descriptions
-UPDATE permission.perm_list SET description = 'Allow a user to cancel a copy transit if the user is at the transit destination or source' WHERE code = 'ABORT_TRANSIT';
-UPDATE permission.perm_list SET description = 'Allow a user to cancel a copy transit if the user is not at the transit source or dest' WHERE code = 'ABORT_REMOTE_TRANSIT'; 
-UPDATE permission.perm_list SET description = 'Allows a user to cancel a transit on a copy with status of LOST' WHERE code = 'ABORT_TRANSIT_ON_LOST';
-UPDATE permission.perm_list SET description = 'Allows a user to cancel a transit on a copy with status of MISSING' WHERE code = 'ABORT_TRANSIT_ON_MISSING';
-
+-- change "abort" to "cancel" in stock perm descriptions
+UPDATE permission.perm_list 
+	SET description = 'Allow a user to cancel a copy transit if the user is at the transit destination or source' 
+	WHERE code = 'ABORT_TRANSIT'
+	AND description = 'Allow a user to abort a copy transit if the user is at the transit destination or source';
+UPDATE permission.perm_list 
+	SET description = 'Allow a user to cancel a copy transit if the user is not at the transit source or dest' 
+	WHERE code = 'ABORT_REMOTE_TRANSIT'
+	AND description = 'Allow a user to abort a copy transit if the user is not at the transit source or dest';
+UPDATE permission.perm_list 
+	SET description = 'Allows a user to cancel a transit on a copy with status of LOST' 
+	WHERE code = 'ABORT_TRANSIT_ON_LOST'
+	AND description = 'Allows a user to abort a transit on a copy with status of LOST';
+UPDATE permission.perm_list 
+	SET description = 'Allows a user to cancel a transit on a copy with status of MISSING' 
+	WHERE code = 'ABORT_TRANSIT_ON_MISSING'
+	AND description = 'Allows a user to abort a transit on a copy with status of MISSING';
 COMMIT;

commit 2e7dfb9cca26c73ea3f6e87637fed03de902e5ca
Author: Chris Sharp <csharp at georgialibraries.org>
Date:   Sat Feb 11 18:39:05 2017 -0500

    LP#1612752 - Adding release notes for Transit Cancel time and terminology change.
    
    Signed-off-by: Chris Sharp <csharp at georgialibraries.org>
    Signed-off-by: Bill Erickson <berickxx at gmail.com>
    Signed-off-by: Galen Charlton <gmc at equinoxinitiative.org>

diff --git a/docs/RELEASE_NOTES_NEXT/Circulation/Transit_Cancel_Time.adoc b/docs/RELEASE_NOTES_NEXT/Circulation/Transit_Cancel_Time.adoc
new file mode 100644
index 0000000..68fa25a
--- /dev/null
+++ b/docs/RELEASE_NOTES_NEXT/Circulation/Transit_Cancel_Time.adoc
@@ -0,0 +1,26 @@
+Transit Cancel Time and Terminology Change
+^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
+
+Transit Cancel Time
++++++++++++++++++++
+
+Previously, Evergreen deleted canceled (aborted) transits from the database.  Now
+the rows in action.transit_copy, action.hold_transit_copy, and action.reservation_transit_copy
+are preserved in the database, though still not visible to the end user in the staff client.
+This allows for better tracking of when transits are canceled for the purposes of knowing
+which staff member canceled the transit, etc.
+
+NOTE: This change may require the re-creation of transit reports to filter out canceled
+transits from the results.  Cloning the template and adding a Base Filter of Cancel Time 
+Is NULL will suffice.
+
+"Canceled Transit" Terminology Change
++++++++++++++++++++++++++++++++++++++
+
+The term "abort" has been replaced with "cancel" in all of the affected user interfaces.
+For internal continuity, however, the following permission codes have not changed:
+
+ * ABORT_TRANSIT
+ * ABORT_REMOTE_TRANSIT
+ * ABORT_TRANSIT_ON_LOST
+ * ABORT_TRANSIT_ON_MISSING

commit 3992d368ac9d08aef664c55876ad155cc396a2a5
Author: Chris Sharp <csharp at georgialibraries.org>
Date:   Mon Aug 15 10:41:52 2016 -0400

    LP#1612752 - s/abort/cancel/ in user interfaces.
    
    Replacing the technical term "abort" with the more
    end-user-understandable "cancel". In client-visible
    language.  The underlying code has retained "abort".
    
    Signed-off-by: Chris Sharp <csharp at georgialibraries.org>
    Signed-off-by: Bill Erickson <berickxx at gmail.com>
    Signed-off-by: Galen Charlton <gmc at equinoxinitiative.org>

diff --git a/Open-ILS/src/extras/ils_events.xml b/Open-ILS/src/extras/ils_events.xml
index 1a17505..fcc2f50 100644
--- a/Open-ILS/src/extras/ils_events.xml
+++ b/Open-ILS/src/extras/ils_events.xml
@@ -130,7 +130,7 @@
 		<desc xml:lang="en-US">The patron's account has expired</desc>
 	</event>
 	<event code='1225' textcode='TRANSIT_ABORT_NOT_ALLOWED'>
-		<desc xml:lang="en-US">The transit on this item may not be aborted due to the state the item is in</desc>
+		<desc xml:lang="en-US">The transit on this item may not be canceled due to the state the item is in</desc>
 	</event>
 
 	<event code='1226' textcode='REFUND_EXCEEDS_DESK_PAYMENTS'>
diff --git a/Open-ILS/src/sql/Pg/950.data.seed-values.sql b/Open-ILS/src/sql/Pg/950.data.seed-values.sql
index 9e0517f..2ec447a 100644
--- a/Open-ILS/src/sql/Pg/950.data.seed-values.sql
+++ b/Open-ILS/src/sql/Pg/950.data.seed-values.sql
@@ -714,9 +714,9 @@ INSERT INTO permission.perm_list ( id, code, description ) VALUES
  ( 105, 'COPY_STATUS_MISSING.override', oils_i18n_gettext( 105, 
     'Allow a user to change the missing status on a copy', 'ppl', 'description' )),
  ( 106, 'ABORT_TRANSIT', oils_i18n_gettext( 106, 
-    'Allow a user to abort a copy transit if the user is at the transit destination or source', 'ppl', 'description' )),
+    'Allow a user to cancel a copy transit if the user is at the transit destination or source', 'ppl', 'description' )),
  ( 107, 'ABORT_REMOTE_TRANSIT', oils_i18n_gettext( 107, 
-    'Allow a user to abort a copy transit if the user is not at the transit source or dest', 'ppl', 'description' )),
+    'Allow a user to cancel a copy transit if the user is not at the transit source or dest', 'ppl', 'description' )),
  ( 108, 'VIEW_ZIP_DATA', oils_i18n_gettext( 108, 
     'Allow a user to query the ZIP code data method', 'ppl', 'description' )),
  ( 109, 'CANCEL_HOLDS', oils_i18n_gettext( 109, 
@@ -1512,9 +1512,9 @@ INSERT INTO permission.perm_list ( id, code, description ) VALUES
  ( 506, 'VIEW_USER_SETTING_TYPE', oils_i18n_gettext(506,
     'Allows viewing of configurable user setting types.', 'ppl', 'description')),
  ( 507, 'ABORT_TRANSIT_ON_LOST', oils_i18n_gettext(507,
-    'Allows a user to abort a transit on a copy with status of LOST', 'ppl', 'description')),
+    'Allows a user to cancel a transit on a copy with status of LOST', 'ppl', 'description')),
  ( 508, 'ABORT_TRANSIT_ON_MISSING', oils_i18n_gettext(508,
-    'Allows a user to abort a transit on a copy with status of MISSING', 'ppl', 'description')),
+    'Allows a user to cancel a transit on a copy with status of MISSING', 'ppl', 'description')),
  ( 509, 'TRANSIT_CHECKIN_INTERVAL_BLOCK.override', oils_i18n_gettext(509,
     'Allows a user to override the TRANSIT_CHECKIN_INTERVAL_BLOCK event', 'ppl', 'description')),
  ( 510, 'UPDATE_PATRON_COLLECTIONS_EXEMPT', oils_i18n_gettext(510,
diff --git a/Open-ILS/src/sql/Pg/upgrade/XXXX-create-transit-cancel-time-column.sql b/Open-ILS/src/sql/Pg/upgrade/XXXX-create-transit-cancel-time-column.sql
index e5cb0b1..a2709f6 100644
--- a/Open-ILS/src/sql/Pg/upgrade/XXXX-create-transit-cancel-time-column.sql
+++ b/Open-ILS/src/sql/Pg/upgrade/XXXX-create-transit-cancel-time-column.sql
@@ -5,4 +5,10 @@ SELECT evergreen.upgrade_deps_block_check('XXXX', :eg_version);
 ALTER TABLE action.transit_copy
 	ADD COLUMN cancel_time TIMESTAMPTZ;
 
+-- change "abort" to "cancel" in perm descriptions
+UPDATE permission.perm_list SET description = 'Allow a user to cancel a copy transit if the user is at the transit destination or source' WHERE code = 'ABORT_TRANSIT';
+UPDATE permission.perm_list SET description = 'Allow a user to cancel a copy transit if the user is not at the transit source or dest' WHERE code = 'ABORT_REMOTE_TRANSIT'; 
+UPDATE permission.perm_list SET description = 'Allows a user to cancel a transit on a copy with status of LOST' WHERE code = 'ABORT_TRANSIT_ON_LOST';
+UPDATE permission.perm_list SET description = 'Allows a user to cancel a transit on a copy with status of MISSING' WHERE code = 'ABORT_TRANSIT_ON_MISSING';
+
 COMMIT;
diff --git a/Open-ILS/src/templates/staff/circ/checkin/t_checkin_table.tt2 b/Open-ILS/src/templates/staff/circ/checkin/t_checkin_table.tt2
index c79561f..2dadf6f 100644
--- a/Open-ILS/src/templates/staff/circ/checkin/t_checkin_table.tt2
+++ b/Open-ILS/src/templates/staff/circ/checkin/t_checkin_table.tt2
@@ -22,7 +22,7 @@
   </eg-grid-action>
   <eg-grid-action 
     handler="abortTransit"
-    label="[% l('Abort Transits') %]">
+    label="[% l('Cancel Transits') %]">
   </eg-grid-action>
 
   <eg-grid-field label="[% l('Alert Msg') %]"   
diff --git a/Open-ILS/src/templates/staff/circ/renew/t_renew.tt2 b/Open-ILS/src/templates/staff/circ/renew/t_renew.tt2
index 6e7d36e..d3debaa 100644
--- a/Open-ILS/src/templates/staff/circ/renew/t_renew.tt2
+++ b/Open-ILS/src/templates/staff/circ/renew/t_renew.tt2
@@ -63,7 +63,7 @@
   <eg-grid-action divider="true"></eg-grid-action>
   <eg-grid-action 
     handler="abortTransit"
-    label="[% l('Abort Transits') %]">
+    label="[% l('Cancel Transits') %]">
   </eg-grid-action>
 
 
diff --git a/Open-ILS/src/templates/staff/circ/share/circ_strings.tt2 b/Open-ILS/src/templates/staff/circ/share/circ_strings.tt2
index 4f9c917..6ad5c78 100644
--- a/Open-ILS/src/templates/staff/circ/share/circ_strings.tt2
+++ b/Open-ILS/src/templates/staff/circ/share/circ_strings.tt2
@@ -27,7 +27,7 @@ s.LOCATION_ALERT_MSG =
     "{{copy.barcode()}}","{{copy.location().name()}}") %]';
 s.MARK_DAMAGED_CONFIRM = '[% l("Mark {{num_items}} items as DAMAGED?") %]';
 s.MARK_MISSING_CONFIRM = '[% l("Mark {{num_items}} items as MISSING?") %]';
-s.ABORT_TRANSIT_CONFIRM = '[% l("Abort {{num_transits}} transits?") %]';
+s.ABORT_TRANSIT_CONFIRM = '[% l("Cancel {{num_transits}} transits?") %]';
 s.ROUTE_TO_HOLDS_SHELF = '[% l("Holds Shelf") %]';
 s.ROUTE_TO_CATALOGING = '[% l("Cataloging") %]';
 s.COPY_IN_TRANSIT = '[% l("Copy is In-Transit") %]';
diff --git a/Open-ILS/src/templates/staff/circ/share/t_copy_in_transit_dialog.tt2 b/Open-ILS/src/templates/staff/circ/share/t_copy_in_transit_dialog.tt2
index 4d38922..022c4cf 100644
--- a/Open-ILS/src/templates/staff/circ/share/t_copy_in_transit_dialog.tt2
+++ b/Open-ILS/src/templates/staff/circ/share/t_copy_in_transit_dialog.tt2
@@ -25,7 +25,7 @@
   </div>
   <div class="modal-footer">
     <input type="submit" class="btn btn-primary" ng-click="ok()"
-        value="[% l('Abort Transit then Checkout') %]"/>
+        value="[% l('Cancel Transit then Checkout') %]"/>
     <button class="btn btn-warning" 
         ng-click="cancel()">[% l('Cancel') %]</button>
   </div>
diff --git a/Open-ILS/web/opac/locale/en-US/lang.dtd b/Open-ILS/web/opac/locale/en-US/lang.dtd
index fdbec28..098d075 100644
--- a/Open-ILS/web/opac/locale/en-US/lang.dtd
+++ b/Open-ILS/web/opac/locale/en-US/lang.dtd
@@ -2139,7 +2139,7 @@
 <!ENTITY staff.server.admin.transit.list.circs.accesskey "L">
 <!ENTITY staff.server.admin.transit.list.edit.label "Edit Item Attributes">
 <!ENTITY staff.server.admin.transit.list.edit.accesskey "E">
-<!ENTITY staff.server.admin.transit.list.abort.label "Abort Transits">
+<!ENTITY staff.server.admin.transit.list.abort.label "Cancel Transits">
 <!ENTITY staff.server.admin.transit.list.save.label "Save Columns">
 <!ENTITY staff.server.admin.cash.title "Evergreen: Cash Reports">
 <!ENTITY staff.server.admin.cash.welcome "Welcome ">
@@ -2457,7 +2457,7 @@
 <!ENTITY staff.circ.checkin_overlay.sel_mark_items_damaged.accesskey "D">
 <!ENTITY staff.circ.checkin_overlay.sel_mark_missing_pieces.label "Mark Item as Missing Pieces">
 <!ENTITY staff.circ.checkin_overlay.sel_mark_missing_pieces.accesskey "M">
-<!ENTITY staff.circ.checkin_overlay.sel_transit_abort.label "Abort Transit">
+<!ENTITY staff.circ.checkin_overlay.sel_transit_abort.label "Cancel Transit">
 <!ENTITY staff.circ.checkin_overlay.sel_spine.label "Print Spine Label">
 <!ENTITY staff.circ.checkin_overlay.sel_spine.accesskey "P">
 <!ENTITY staff.circ.checkin_overlay.save_columns.label "Save Columns">
@@ -2511,7 +2511,7 @@
 <!ENTITY staff.circ.renew_overlay.sel_edit.accesskey "E">
 <!ENTITY staff.circ.renew_overlay.sel_mark_items_damaged.label "Mark Item Damaged">
 <!ENTITY staff.circ.renew_overlay.sel_mark_items_damaged.accesskey "D">
-<!ENTITY staff.circ.renew_overlay.sel_transit_abort.label "Abort Transit">
+<!ENTITY staff.circ.renew_overlay.sel_transit_abort.label "Cancel Transit">
 <!ENTITY staff.circ.renew_overlay.sel_spine.label "Print Spine Label">
 <!ENTITY staff.circ.renew_overlay.sel_spine.accesskey "P">
 <!ENTITY staff.circ.renew_overlay.save_columns.label "Save Columns">
@@ -2590,7 +2590,7 @@
 <!ENTITY staff.circ.copy_status_overlay.sel_mark_items_damaged.accesskey "D">
 <!ENTITY staff.circ.copy_status_overlay.sel_mark_items_missing.label "Mark Item Missing">
 <!ENTITY staff.circ.copy_status_overlay.sel_mark_items_missing.accesskey "M">
-<!ENTITY staff.circ.copy_status_overlay.sel_transit_abort.label "Abort Transits">
+<!ENTITY staff.circ.copy_status_overlay.sel_transit_abort.label "Cancel Transits">
 <!ENTITY staff.circ.copy_status_overlay.sel_checkin.label "Check In Items">
 <!ENTITY staff.circ.copy_status_overlay.sel_checkin.accesskey "N">
 <!ENTITY staff.circ.copy_status_overlay.sel_renew.label "Renew Items">
diff --git a/Open-ILS/xul/staff_client/server/locale/en-US/circ.properties b/Open-ILS/xul/staff_client/server/locale/en-US/circ.properties
index 7f3798c..0f1d0c9 100644
--- a/Open-ILS/xul/staff_client/server/locale/en-US/circ.properties
+++ b/Open-ILS/xul/staff_client/server/locale/en-US/circ.properties
@@ -63,7 +63,7 @@ staff.circ.checkout.account.expired=This account has expired and may not circula
 staff.circ.checkout.item_due=This item was due on %1$s.
 staff.circ.checkout.normal_checkin_then_checkout=Normal Checkin then Checkout
 staff.circ.checkout.forgiving_checkin_then_checkout=Forgiving Checkin then Checkout
-staff.circ.checkout.abort_transit_then_checkout=Abort Transit then Checkout
+staff.circ.checkout.abort_transit_then_checkout=Cancel Transit then Checkout
 staff.circ.checkout.offer_renewal=Renew Item
 staff.circ.checkout.network_failure=There was a network failure.
 staff.circ.checkout.copy_status=Copy status = %1$s
@@ -222,13 +222,13 @@ staff.circ.print_list_template.import_results=Imported these templates: %1$s
 staff.circ.print_list_template.reload=Please reload this interface.
 staff.circ.print_list_template.import.error=Error exporting templates
 staff.circ.print_list_template.tab_name=Receipt Template Editor
-staff.circ.utils.abort_transits.confirm=Are you sure you would like to abort transits for copies: %1$s?
-staff.circ.utils.abort_transits.title=Aborting Transits
+staff.circ.utils.abort_transits.confirm=Are you sure you would like to cancel transits for copies: %1$s?
+staff.circ.utils.abort_transits.title=Canceling Transits
 staff.circ.utils.yes=Yes
 staff.circ.utils.no=No
 staff.circ.utils.abort_transits.not_allowed=Copy ID = %1$s
-staff.circ.utils.abort_transits.not_found=This item was no longer in transit at the time of the abort.  Perhaps this happened from a stale display?
-staff.circ.utils.abort_transits.unexpected_error=Transit not likely aborted.
+staff.circ.utils.abort_transits.not_found=This item was no longer in transit at the time of the cancellation.  Perhaps this happened from a stale display?
+staff.circ.utils.abort_transits.unexpected_error=Transit not likely canceled.
 staff.circ.utils.retrieve_patron.failure=Problem retrieving patron.
 staff.circ.utils.retrieve_copy.failure=Problem retrieving copy details.
 staff.circ.utils.retrieve_circs.failure=Problem retrieving circulations.

commit 1cedb423902810e9df5355ab18c7ca7e18d5391d
Author: Chris Sharp <csharp at georgialibraries.org>
Date:   Fri Aug 12 13:41:25 2016 -0400

    LP#1612752 - Add cancel_time to action.transit_copy and friends.
    
    It is useful to have keep action.transit_copy rows intact when
    doing forensics on what happens after a staff member cancels a
    transit.
    
    Signed-off-by: Chris Sharp <csharp at georgialibraries.org>
    Signed-off-by: Bill Erickson <berickxx at gmail.com>
    Signed-off-by: Galen Charlton <gmc at equinoxinitiative.org>

diff --git a/Open-ILS/examples/fm_IDL.xml b/Open-ILS/examples/fm_IDL.xml
index b1d287e..eaaa780 100644
--- a/Open-ILS/examples/fm_IDL.xml
+++ b/Open-ILS/examples/fm_IDL.xml
@@ -2362,6 +2362,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 			<field reporter:label="Prev Destination" name="prev_dest" reporter:datatype="org_unit"/>
 			<field reporter:label="Send Date/Time" name="source_send_time" reporter:datatype="timestamp"/>
 			<field reporter:label="Transited Copy" name="target_copy" reporter:datatype="link"/>
+			<field reporter:label="Cancel Date/Time" name="cancel_time" reporter:datatype="timestamp"/>
 			<field reporter:label="Hold Transit" name="hold_transit_copy" oils_persist:virtual="true" reporter:datatype="link"/>
 		</fields>
 		<links>
@@ -7397,6 +7398,7 @@ SELECT  usr,
 			<field reporter:label="Transited Copy" name="target_copy" reporter:datatype="link"/>
 			<field reporter:label="Base Transit" name="transit_copy" oils_persist:virtual="true" reporter:datatype="link"/>
 			<field reporter:label="Prev Destination Library" name="prev_dest" reporter:datatype="org_unit"/>
+			<field reporter:label="Cancel Date/Time" name="cancel_time" reporter:datatype="timestamp"/>
 		</fields>
 		<links>
 			<link field="transit_copy" reltype="might_have" key="id" map="" class="atc"/>
@@ -7432,6 +7434,7 @@ SELECT  usr,
 			<field reporter:label="Transited Copy" name="target_copy" reporter:datatype="link"/>
 			<field reporter:label="Base Transit" name="transit_copy" oils_persist:virtual="true" reporter:datatype="link"/>
 			<field reporter:label="Prev Destination Library" name="prev_dest" reporter:datatype="org_unit"/>
+			<field reporter:label="Cancel Date/Time" name="cancel_time" reporter:datatype="timestamp"/>
 		</fields>
 		<links>
 			<link field="transit_copy" reltype="might_have" key="id" map="" class="atc"/>
@@ -11133,6 +11136,7 @@ SELECT  usr,
 			<field reporter:label="Send Date/Time" name="source_send_time" reporter:datatype="timestamp"/>
 			<field reporter:label="Transited Copy" name="target_copy" reporter:datatype="link"/>
 			<field reporter:label="Hold Transit" name="hold_transit_copy" oils_persist:virtual="true" reporter:datatype="link"/>
+			<field reporter:label="Cancel Date/Time" name="cancel_time" reporter:datatype="timestamp"/>
 		</fields>
 		<links>
 			<link field="hold_transit_copy" reltype="might_have" key="id" map="" class="ahtc"/>
diff --git a/Open-ILS/src/perlmods/lib/OpenILS/Application/AppUtils.pm b/Open-ILS/src/perlmods/lib/OpenILS/Application/AppUtils.pm
index b24a0db..bcfc81b 100644
--- a/Open-ILS/src/perlmods/lib/OpenILS/Application/AppUtils.pm
+++ b/Open-ILS/src/perlmods/lib/OpenILS/Application/AppUtils.pm
@@ -411,7 +411,7 @@ sub fetch_hold_transit_by_hold {
 
     $transit = $self->simplereq(
         'open-ils.cstore',
-        'open-ils.cstore.direct.action.hold_transit_copy.search', { hold => $holdid } );
+        'open-ils.cstore.direct.action.hold_transit_copy.search', { hold => $holdid, cancel_time => undef } );
 
     $evt = OpenILS::Event->new('ACTION_HOLD_TRANSIT_COPY_NOT_FOUND', holdid => $holdid) unless $transit;
 
@@ -978,7 +978,7 @@ sub fetch_open_transit_by_copy {
     my($transit, $evt);
     $transit = $self->cstorereq(
         'open-ils.cstore.direct.action.transit_copy.search',
-        { target_copy => $copyid, dest_recv_time => undef });
+        { target_copy => $copyid, dest_recv_time => undef, cancel_time => undef });
     $evt = OpenILS::Event->new('ACTION_TRANSIT_COPY_NOT_FOUND') unless $transit;
     return ($transit, $evt);
 }
diff --git a/Open-ILS/src/perlmods/lib/OpenILS/Application/Booking.pm b/Open-ILS/src/perlmods/lib/OpenILS/Application/Booking.pm
index bb38731..3727011 100644
--- a/Open-ILS/src/perlmods/lib/OpenILS/Application/Booking.pm
+++ b/Open-ILS/src/perlmods/lib/OpenILS/Application/Booking.pm
@@ -1044,7 +1044,7 @@ sub capture_reservation {
 
         # need to transit the item ... is it already in transit?
         my $transit = $e->search_action_reservation_transit_copy(
-            {"reservation" => $res_id, "dest_recv_time" => undef}
+            {"reservation" => $res_id, "dest_recv_time" => undef, cancel_time => undef}
         )->[0];
 
         if (!$transit) { # not yet in transit
diff --git a/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ.pm b/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ.pm
index 4d9f881..8f439e5 100644
--- a/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ.pm
+++ b/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ.pm
@@ -1078,7 +1078,7 @@ sub copy_details {
     OpenILS::Application::Circ::Holds::flesh_hold_transits([$hold]) if $hold;
 
     my $transit = $e->search_action_transit_copy(
-        { target_copy => $copy_id, dest_recv_time => undef } )->[0];
+        { target_copy => $copy_id, dest_recv_time => undef, cancel_time => undef } )->[0];
 
     # find the most recent circulation for the requested copy,
     # be it active, completed, or aged.
diff --git a/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Circulate.pm b/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Circulate.pm
index e12828c..21b875d 100644
--- a/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Circulate.pm
+++ b/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Circulate.pm
@@ -176,7 +176,7 @@ sub run_method {
             my $res_id_list = [ map { $_->id } @$resources ];
             my $transit = $circulator->editor->search_action_reservation_transit_copy(
                 [
-                    { target_copy => $res_id_list, dest => $circulator->circ_lib, dest_recv_time => undef },
+                    { target_copy => $res_id_list, dest => $circulator->circ_lib, dest_recv_time => undef, cancel_time => undef },
                     { order_by => { artc => 'source_send_time' }, limit => 1 }
                 ]
             )->[0]; # Any transit for this barcode?
@@ -2208,7 +2208,7 @@ sub check_transit_checkin_interval {
     # capture the transit so we don't have to fetch it again later during checkin
     $self->transit(
         $self->editor->search_action_transit_copy(
-            {target_copy => $self->copy->id, dest_recv_time => undef}
+            {target_copy => $self->copy->id, dest_recv_time => undef, cancel_time => undef}
         )->[0]
     ); 
 
@@ -2397,7 +2397,7 @@ sub do_checkin {
     if( $self->copy and !$self->transit ) {
         $self->transit(
             $self->editor->search_action_transit_copy(
-                { target_copy => $self->copy->id, dest_recv_time => undef }
+                { target_copy => $self->copy->id, dest_recv_time => undef, cancel_time => undef }
             )->[0]
         ); 
     }
diff --git a/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Holds.pm b/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Holds.pm
index 024a0e6..9c1ca72 100644
--- a/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Holds.pm
+++ b/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Holds.pm
@@ -620,7 +620,7 @@ sub retrieve_holds {
 
         $hold->transit(
             $e->search_action_hold_transit_copy([
-                {hold => $hold->id},
+                {hold => $hold->id, cancel_time => undef},
                 {order_by => {ahtc => 'source_send_time desc'}, limit => 1}])->[0]
         );
 
@@ -807,7 +807,7 @@ sub cancel_hold {
 
             my $hid = $hold->id;
             $logger->warn("! canceling hold [$hid] that is in transit");
-            my $transid = $e->search_action_hold_transit_copy({hold=>$hold->id},{idlist=>1})->[0];
+            my $transid = $e->search_action_hold_transit_copy({hold=>$hold->id,cancel_time=>undef},{idlist=>1})->[0];
 
             if( $transid ) {
                 my $trans = $e->retrieve_action_transit_copy($transid);
@@ -1011,7 +1011,7 @@ sub update_hold_impl {
 
             # update the transit to reflect the new pickup location
             my $transit = $e->search_action_hold_transit_copy(
-                {hold=>$hold->id, dest_recv_time => undef})->[0]
+                {hold=>$hold->id, cancel_time => undef, dest_recv_time => undef})->[0]
                 or return $e->die_event;
 
             $transit->prev_dest($transit->dest); # mark the previous destination on the transit
@@ -1293,6 +1293,7 @@ sub _hold_status {
         my $transit    = $e->search_action_hold_transit_copy({
                             hold           => $hold->id,
                             target_copy    => $copy->id,
+                            cancel_time     => undef,
                             dest_recv_time => {'!=' => undef},
                          })->[0];
         my $start_time = ($transit) ? $transit->dest_recv_time : $hold->capture_time;
@@ -1972,7 +1973,7 @@ sub _reset_hold {
             # We don't want the copy to remain "in transit"
             $copy->status(OILS_COPY_STATUS_RESHELVING);
             $logger->warn("! reseting hold [$hid] that is in transit");
-            my $transid = $e->search_action_hold_transit_copy({hold=>$hold->id},{idlist=>1})->[0];
+            my $transid = $e->search_action_hold_transit_copy({hold=>$hold->id,cancel_time=>undef},{idlist=>1})->[0];
 
             if( $transid ) {
                 my $trans = $e->retrieve_action_transit_copy($transid);
@@ -2049,7 +2050,7 @@ sub flesh_hold_transits {
             $apputils->simplereq(
                 'open-ils.cstore',
                 "open-ils.cstore.direct.action.hold_transit_copy.search.atomic",
-                { hold => $hold->id },
+                { hold => $hold->id, cancel_time => undef },
                 { order_by => { ahtc => 'id desc' }, limit => 1 }
             )->[0]
         );
diff --git a/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Transit.pm b/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Transit.pm
index fad7923..f627b99 100644
--- a/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Transit.pm
+++ b/Open-ILS/src/perlmods/lib/OpenILS/Application/Circ/Transit.pm
@@ -204,7 +204,7 @@ sub abort_transit {
     } elsif( $copy ) {
 
         $transit = $e->search_action_transit_copy(
-            { target_copy => $copy->id, dest_recv_time => undef })->[0];
+            { target_copy => $copy->id, dest_recv_time => undef, cancel_time => undef })->[0];
         return $e->event unless $transit;
     }
 
@@ -241,7 +241,9 @@ sub __abort_transit {
 
     my $holdtransit = $e->retrieve_action_hold_transit_copy($transit->id);
 
-    return $e->die_event unless $e->delete_action_transit_copy($transit);
+    # rather than deleting the transit row, set the cancel_time
+    $transit->cancel_time('now');
+    return $e->die_event unless $e->update_action_transit_copy($transit);
 
     # Only change the copy status if the copy status is "In Transit."
     if ($copy->status == OILS_COPY_STATUS_IN_TRANSIT) {
@@ -297,7 +299,7 @@ sub get_open_copy_transit {
     return $e->event unless $e->checkauth;
     return $e->event unless $e->allowed('VIEW_USER'); # XXX rely on editor perms
     my $t = $e->search_action_transit_copy(
-        { target_copy => $copyid, dest_recv_time => undef });
+        { target_copy => $copyid, dest_recv_time => undef, cancel_time => undef });
     return $e->event unless @$t;
     return $$t[0];
 }
@@ -316,7 +318,8 @@ sub fetch_transit_by_copy {
     my $t = $e->search_action_transit_copy(
         {
             target_copy => $copyid,
-            dest_recv_time => undef
+            dest_recv_time => undef,
+            cancel_time => undef
         }
     )->[0];
     return $e->event unless $t;
@@ -340,7 +343,7 @@ sub transits_by_lib {
     return $e->event unless $e->allowed('VIEW_CIRCULATIONS'); # eh.. basically the same permission
 
     my $order_by = {order_by => { atc => 'source_send_time' }};
-    my $search = { dest_recv_time => undef };
+    my $search = { dest_recv_time => undef, cancel_time => undef };
 
     if($end_date) {
         if($start_date) {
diff --git a/Open-ILS/src/perlmods/lib/OpenILS/Application/Storage/CDBI/action.pm b/Open-ILS/src/perlmods/lib/OpenILS/Application/Storage/CDBI/action.pm
index 8a33f4f..5a59393 100644
--- a/Open-ILS/src/perlmods/lib/OpenILS/Application/Storage/CDBI/action.pm
+++ b/Open-ILS/src/perlmods/lib/OpenILS/Application/Storage/CDBI/action.pm
@@ -124,7 +124,7 @@ __PACKAGE__->table('action_hold_transit_copy');
 __PACKAGE__->columns(Primary => 'id');
 __PACKAGE__->columns(Essential => qw/source dest persistant_transfer target_copy
                      source_send_time dest_recv_time prev_hop prev_dest
-                     copy_status hold/);
+                     cancel_time copy_status hold/);
 
 #-------------------------------------------------------------------------------
 
@@ -134,7 +134,7 @@ __PACKAGE__->table('action_reservation_transit_copy');
 __PACKAGE__->columns(Primary => 'id');
 __PACKAGE__->columns(Essential => qw/source dest persistant_transfer target_copy
                      source_send_time dest_recv_time prev_hop prev_dest
-                     copy_status reservation/);
+                     cancel_time copy_status reservation/);
 
 #-------------------------------------------------------------------------------
 
@@ -144,7 +144,7 @@ __PACKAGE__->table('action_transit_copy');
 __PACKAGE__->columns(Primary => 'id');
 __PACKAGE__->columns(Essential => qw/source dest persistant_transfer target_copy
                      source_send_time dest_recv_time prev_hop prev_dest
-                     copy_status/);
+                     cancel_time copy_status/);
 
 #-------------------------------------------------------------------------------
 
diff --git a/Open-ILS/src/perlmods/lib/OpenILS/Application/Storage/Publisher/action.pm b/Open-ILS/src/perlmods/lib/OpenILS/Application/Storage/Publisher/action.pm
index 6e2ae2c..c6118f2 100644
--- a/Open-ILS/src/perlmods/lib/OpenILS/Application/Storage/Publisher/action.pm
+++ b/Open-ILS/src/perlmods/lib/OpenILS/Application/Storage/Publisher/action.pm
@@ -420,6 +420,7 @@ sub build_hold_sort_clause {
                 COALESCE(dest_recv_time, source_send_time) AS moment
             FROM action.transit_copy
             WHERE target_copy = %d
+            AND cancel_time IS NULL
             ORDER BY moment DESC LIMIT 1
         ) UNION (
             SELECT
@@ -504,7 +505,8 @@ sub build_hold_sort_clause {
         WHERE
             atc.target_copy = %d AND
             (atc.dest = %d OR atc.source = %d) AND
-            atc.dest_recv_time >= NOW() - (SELECT value FROM go_home_interval)
+            atc.dest_recv_time >= NOW() - (SELECT value FROM go_home_interval) AND
+            atc.cancel_time IS NULL
     ) AS result FROM copy_has_not_been_home
 ) !, $cp->id, $cp->circ_lib, $cp->circ_lib);
         $joins .= " JOIN copy_has_not_been_home_even_to_idle ON (true) ";
diff --git a/Open-ILS/src/perlmods/lib/OpenILS/SIP/Item.pm b/Open-ILS/src/perlmods/lib/OpenILS/SIP/Item.pm
index 2a98825..b32fb01 100644
--- a/Open-ILS/src/perlmods/lib/OpenILS/SIP/Item.pm
+++ b/Open-ILS/src/perlmods/lib/OpenILS/SIP/Item.pm
@@ -170,7 +170,8 @@ sub fetch_transit {
         my $transit = $e->search_action_transit_copy([
             {
                 target_copy    => $copy->id,    # NOT barcode ($self->id)
-                dest_recv_time => undef
+                dest_recv_time => undef,
+                cancel_time => undef
             },
             {
                 flesh => 1,
diff --git a/Open-ILS/src/sql/Pg/090.schema.action.sql b/Open-ILS/src/sql/Pg/090.schema.action.sql
index bed82b7..11ee4c3 100644
--- a/Open-ILS/src/sql/Pg/090.schema.action.sql
+++ b/Open-ILS/src/sql/Pg/090.schema.action.sql
@@ -494,7 +494,8 @@ CREATE TABLE action.transit_copy (
 	prev_hop		INT				REFERENCES action.transit_copy (id) DEFERRABLE INITIALLY DEFERRED,
 	copy_status		INT				NOT NULL REFERENCES config.copy_status (id) DEFERRABLE INITIALLY DEFERRED,
 	persistant_transfer	BOOL				NOT NULL DEFAULT FALSE,
-	prev_dest       INT				REFERENCES actor.org_unit (id) DEFERRABLE INITIALLY DEFERRED
+	prev_dest		INT				REFERENCES actor.org_unit (id) DEFERRABLE INITIALLY DEFERRED,
+	cancel_time		TIMESTAMP WITH TIME ZONE
 );
 CREATE INDEX active_transit_dest_idx ON "action".transit_copy (dest); 
 CREATE INDEX active_transit_source_idx ON "action".transit_copy (source);
diff --git a/Open-ILS/src/sql/Pg/upgrade/XXXX-create-transit-cancel-time-column.sql b/Open-ILS/src/sql/Pg/upgrade/XXXX-create-transit-cancel-time-column.sql
new file mode 100644
index 0000000..e5cb0b1
--- /dev/null
+++ b/Open-ILS/src/sql/Pg/upgrade/XXXX-create-transit-cancel-time-column.sql
@@ -0,0 +1,8 @@
+BEGIN;
+
+SELECT evergreen.upgrade_deps_block_check('XXXX', :eg_version);
+
+ALTER TABLE action.transit_copy
+	ADD COLUMN cancel_time TIMESTAMPTZ;
+
+COMMIT;

-----------------------------------------------------------------------

Summary of changes:
 Open-ILS/examples/fm_IDL.xml                       |    4 +++
 Open-ILS/src/extras/ils_events.xml                 |    2 +-
 .../perlmods/lib/OpenILS/Application/AppUtils.pm   |    4 +-
 .../perlmods/lib/OpenILS/Application/Booking.pm    |    2 +-
 .../lib/OpenILS/Application/Cat/AssetCommon.pm     |    7 +++--
 .../src/perlmods/lib/OpenILS/Application/Circ.pm   |    2 +-
 .../lib/OpenILS/Application/Circ/Circulate.pm      |    6 ++--
 .../perlmods/lib/OpenILS/Application/Circ/Holds.pm |   11 ++++----
 .../lib/OpenILS/Application/Circ/Transit.pm        |   13 ++++++----
 .../lib/OpenILS/Application/Storage/CDBI/action.pm |    6 ++--
 .../Application/Storage/Publisher/action.pm        |    4 ++-
 Open-ILS/src/perlmods/lib/OpenILS/SIP/Item.pm      |    3 +-
 Open-ILS/src/sql/Pg/002.schema.config.sql          |    2 +-
 Open-ILS/src/sql/Pg/090.schema.action.sql          |    3 +-
 Open-ILS/src/sql/Pg/950.data.seed-values.sql       |    8 +++---
 ...45.schema.create-transit-cancel-time-column.sql |   25 +++++++++++++++++++
 .../staff/circ/checkin/t_checkin_table.tt2         |    2 +-
 .../src/templates/staff/circ/renew/t_renew.tt2     |    2 +-
 .../templates/staff/circ/share/circ_strings.tt2    |    2 +-
 .../staff/circ/share/t_abort_transit_dialog.tt2    |    8 +++---
 .../staff/circ/share/t_copy_in_transit_dialog.tt2  |    2 +-
 .../src/templates/staff/circ/transits/t_list.tt2   |    2 +-
 .../web/js/ui/default/staff/circ/transits/list.js  |    3 +-
 Open-ILS/web/opac/locale/en-US/lang.dtd            |    8 +++---
 .../server/locale/en-US/circ.properties            |   10 ++++----
 .../Circulation/Transit_Cancel_Time.adoc           |   26 ++++++++++++++++++++
 26 files changed, 116 insertions(+), 51 deletions(-)
 create mode 100644 Open-ILS/src/sql/Pg/upgrade/1045.schema.create-transit-cancel-time-column.sql
 create mode 100644 docs/RELEASE_NOTES_NEXT/Circulation/Transit_Cancel_Time.adoc


hooks/post-receive
diff --git a/Open-ILS/src/perlmods/lib/OpenILS/Application/Cat/AssetCommon.pm b/Open-ILS/src/perlmods/lib/OpenILS/Application/Cat/AssetCommon.pm
index a07c9be..69e5b4b 100644
--- a/Open-ILS/src/perlmods/lib/OpenILS/Application/Cat/AssetCommon.pm
+++ b/Open-ILS/src/perlmods/lib/OpenILS/Application/Cat/AssetCommon.pm
@@ -428,12 +428,13 @@ sub delete_copy {
     $copy->edit_date('now');
     $editor->update_asset_copy($copy) or return $editor->event;
 
     # Delete any open transits for this copy
     my $transits = $editor->search_action_transit_copy(
-        { target_copy=>$copy->id, dest_recv_time => undef } );
+        { target_copy=>$copy->id, dest_recv_time => undef, cancel_time => undef } );
 
     for my $t (@$transits) {
-        $editor->delete_action_transit_copy($t)
+        $t->cancel_time('now');
+        $editor->update_action_transit_copy($t)
             or return $editor->event;
     }
 
@@ -428,12 +428,13 @@ sub delete_copy {
     $editor->update_asset_copy($copy) or return $editor->event;
 
-    # Delete any open transits for this copy
+    # Cancel any open transits for this copy
     my $transits = $editor->search_action_transit_copy(
-- 
Evergreen ILS




More information about the open-ils-commits mailing list